@@ -3,6 +3,8 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
+from typing import List
+
 from jupyter_client.channelsabc import HBChannelABC
 
 # -----------------------------------------------------------------------------
@@ -13,20 +15,24 @@ from jupyter_client.channelsabc import HBChannelABC
 class InProcessChannel:
     """Base class for in-process channels."""
 
-    proxy_methods = []
+    proxy_methods: List[object] = []
 
     def __init__(self, client=None):
+        """Initialize the channel."""
         super().__init__()
         self.client = client
         self._is_alive = False
 
     def is_alive(self):
+        """Test if the channel is alive."""
         return self._is_alive
 
     def start(self):
+        """Start the channel."""
         self._is_alive = True
 
     def stop(self):
+        """Stop the channel."""
         self._is_alive = False
 
     def call_handlers(self, msg):
@@ -34,10 +40,11 @@ class InProcessChannel:
 
         Subclasses should override this method to handle incoming messages.
         """
-        raise NotImplementedError("call_handlers must be defined in a subclass.")
+        msg = "call_handlers must be defined in a subclass."
+        raise NotImplementedError(msg)
 
     def flush(self, timeout=1.0):
-        pass
+        """Flush the channel."""
 
     def call_handlers_later(self, *args, **kwds):
         """Call the message handlers later.
@@ -68,27 +75,34 @@ class InProcessHBChannel:
     time_to_dead = 3.0
 
     def __init__(self, client=None):
+        """Initialize the channel."""
         super().__init__()
         self.client = client
         self._is_alive = False
         self._pause = True
 
     def is_alive(self):
+        """Test if the channel is alive."""
         return self._is_alive
 
     def start(self):
+        """Start the channel."""
         self._is_alive = True
 
     def stop(self):
+        """Stop the channel."""
         self._is_alive = False
 
     def pause(self):
+        """Pause the channel."""
         self._pause = True
 
     def unpause(self):
+        """Unpause the channel."""
         self._pause = False
 
     def is_beating(self):
+        """Test if the channel is beating."""
         return not self._pause
 
 
